@@ -33,10 +33,6 @@ import xarray as xr
 from .. import xarray_behave as xb
 from .. import loaders as ld
 from .. import event_utils
-# try:
-#     from .. import deepss
-# except ImportError:
-#     pass
 
 from . import colormaps
 from . import utils
@@ -81,6 +77,7 @@ class MainWindow(pg.QtGui.QMainWindow):
         file.addSeparator()
         self.add_keyed_menuitem(file, "Save swap files", self.save_swaps)
         self.add_keyed_menuitem(file, "Save annotations", self.save_annotations)
+        self.add_keyed_menuitem(file, "Export annotations to csv", self.export_annotations)
         self.add_keyed_menuitem(file, "Save dataset", self.save_dataset)
         file.addSeparator()
         file.addAction("Exit")
@@ -138,6 +135,43 @@ class MainWindow(pg.QtGui.QMainWindow):
                 xb.save(savefilename, self.ds.song_events.to_dataset())
                 logging.info(f'   Done.')
 
+    def export_annotations(self, qt_keycode=None):
+        if 'song_events' in self.ds:
+            try:
+                import pandas as pd
+            except ImportError:
+                logging.warning('Need to install pandas for export to work: `conda install pandas`.')
+                return
+
+            try:
+                savefilename = Path(self.ds.attrs['root'], self.ds.attrs['res_path'], self.ds.attrs['datename'],
+                                    f"{self.ds.attrs['datename']}_annotations.csv")
+            except KeyError:
+                savefilename = ''
+            savefilename, _ = QtWidgets.QFileDialog.getSaveFileName(self, 'Save annotations to', str(savefilename),
+                                                                    filter="csv files (*.csv);;all files (*)")
+            if len(savefilename):
+                logging.info('   Updating song events.')
+                self.ds = event_utils.eventtimes_to_traces(self.ds, self.event_times)
+                logging.info(f'   Formatting annotations for export.')
+
+                df = pd.DataFrame()
+                for event_name, event_data in self.event_times.items():
+                    if event_data.ndim > 1 and event_data.shape[1] == 2:  # segments
+                        df = pd.concat([df, pd.DataFrame({event_name + '_onsets': event_data[:, 0]})],
+                                        axis=1)
+                        df = pd.concat([df, pd.DataFrame({event_name + '_offsets': event_data[:, 1]})],
+                                        axis=1)
+                    elif event_data.ndim == 1:
+                        df = pd.concat([df, pd.DataFrame({event_name: event_data})],
+                                        axis=1)
+                    else:
+                        raise ValueError("Unexpected format - either shape should be (N,) for events and (N, 2) for segments.")
+
+                logging.info(f'   Saving annotations to {savefilename}.')
+                df.to_csv(savefilename, index=False)
+                logging.info(f'   Done.')
+
     @classmethod
     def from_wav(cls, wav_filename=None, app=None, qt_keycode=None, events_string='',
                  spec_freq_min=None, spec_freq_max=None, target_samplingrate=None,
@@ -640,31 +674,15 @@ class PSV(MainWindow):
         view_audio.addSeparator()
         self.view_audio = view_audio
 
-        # self.eventList = []
-        # if 'song_events' in ds:
-        #     self.eventList = [(cnt, evt) for cnt, evt in enumerate(self.ds.event_types.values)]
-        #     for event_type in self.eventList:
-        #         self.cb.addItem("Add " + event_type[1])
-
-        # # populate menu with event types so we can catch keys for them - allows changing event type for annotation using numeric keys
-        # for ii in range(self.cb.count()):
-        #     # key = eval(f'"{ii}') if ii<10 else None
-        #     key = str(ii) if ii<10 else None
-        #     key_label = f"({key})" if key is not None else ''
-        #     self.cb.setItemText(ii, f"{self.cb.itemText(ii)} {key_label}")
-        #     menu_item =self.add_keyed_menuitem(self.view_audio,
-        #                                        self.cb.itemText(ii),
-        #                                        self.change_event_type,
-        #                                        key)
-        #     self.event_items.append(menu_item)
-
         # CHANNEL selector
         self.cb2 = pg.QtGui.QComboBox()
         if 'song' in self.ds:
             self.cb2.addItem("Merged channels")
+
         if 'song_raw' in self.ds:
             for chan in range(self.ds.song_raw.shape[1]):
                 self.cb2.addItem("Channel " + str(chan))
+
         self.cb2.currentIndexChanged.connect(self.update_xy)
         self.cb2.setCurrentIndex(0)
         self.hl.addWidget(self.cb2)
@@ -1357,20 +1375,20 @@ class PSV(MainWindow):
             self.update_eventtype_selector()
 
     def update_eventtype_selector(self):
-        # update EVENT TYPE selector
-        # remove old
 
-        while self.cb.count():
+        while self.cb.count() > 0:
             self.cb.removeItem(0)
 
         self.cb.addItem("No annotation")
         if 'event_types' in self.ds:
             self.eventList = [(cnt, evt) for cnt, evt in enumerate(self.ds.event_types.values)]
+            self.eventList = sorted(self.eventList)
         else:
             self.eventList = []
 
         for event_type in self.eventList:
             self.cb.addItem("Add " + event_type[1])
+
         self.cb.currentIndexChanged.connect(self.update_xy)
         self.cb.setCurrentIndex(0)
 
@@ -1391,12 +1409,18 @@ class PSV(MainWindow):
             key = str(ii) if ii<10 else None
             key_label = f"({key})" if key is not None else ''
             self.cb.setItemText(ii, f"{self.cb.itemText(ii)} {key_label}")
-            menu_item =self.add_keyed_menuitem(self.view_audio,
+            menu_item = self.add_keyed_menuitem(self.view_audio,
                                                 self.cb.itemText(ii),
                                                 self.change_event_type,
                                                 key)
             self.event_items.append(menu_item)
 
+        # color events in combobox as in slice_view and spec_view
+        children = self.cb.children()
+        itemList = children[0]
+        for ii, col in zip(range(1, itemList.rowCount()), self.eventype_colors):
+            itemList.item(ii).setForeground(QtGui.QColor(*col))
+
 
 def main(source: str = '', *, events_string: str = '', target_samplingrate: float = None,
          spec_freq_min: float = None, spec_freq_max: float=None, box_size: int = 200,
